@@ -1,8 +1,8 @@
 #![warn(missing_docs)]
 
 //! **noodles** is a library for handling various bioinformatics file formats. It currently
-//! includes readers and writers for BAM 1.6, BCF 2.2, BGZF, CRAM 3.0, CSI, FASTA, FASTQ, GFF3, SAM
-//! 1.6, tabix, and VCF 4.3.
+//! includes readers and writers for BAM 1.6, BCF 2.2, BGZF, CRAM 3.0, CSI, FASTA, FASTQ, GFF3, GTF
+//! 2.2, SAM 1.6, tabix, and VCF 4.3.
 
 #[cfg(feature = "bam")]
 #[doc(inline)]
@@ -40,6 +40,10 @@ pub use noodles_fastq as fastq;
 #[doc(inline)]
 pub use noodles_gff as gff;
 
+#[cfg(feature = "gtf")]
+#[doc(inline)]
+pub use noodles_gtf as gtf;
+
 #[cfg(feature = "sam")]
 #[doc(inline)]
 pub use noodles_sam as sam;
